#
# spec file for package otpclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define uclname OTPClient
Name:           otpclient
Version:        4.0.2
Release:        1.4
Summary:        Simple GTK+ client for managing TOTP and HOTP
License:        GPL-3.0-or-later
Group:          Productivity/Security
URL:            https://github.com/paolostivanin/%{name}
Source0:        https://github.com/paolostivanin/%{name}/archive/v%{version}.tar.gz
Source1:        https://github.com/paolostivanin/%{uclname}/releases/download/v%{version}/v%{version}.tar.gz.asc
Source2:        otpclient.keyring
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libcotp-devel >= 3.0.0
BuildRequires:  libgcrypt-devel >= 1.10.1
BuildRequires:  libjansson-devel >= 2.12.0
BuildRequires:  libpng16-devel >= 1.6.30
BuildRequires:  libprotobuf-c-devel >= 1.3.0
BuildRequires:  libsecret-devel >= 0.20
BuildRequires:  libuuid-devel >= 2.34.0
BuildRequires:  libzbar-devel >= 0.20.0
BuildRequires:  pkgconfig
BuildRequires:  protobuf-devel >= 3.6.0
BuildRequires:  qrencode-devel >= 4.0.2
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0) >= 2.68
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24

%description
Highly secure and easy to use GTK+ software for two-factor authentication
that supports both Time-based One-time Passwords (TOTP) and
HMAC-Based One-Time Passwords (HOTP).

%prep
%setup -q -n %{uclname}-%{version}

%build
%cmake \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DBUILD_GUI=ON \
    -DBUILD_CLI=ON
%cmake_build

%install
%cmake_install
%suse_update_desktop_file -r com.github.paolostivanin.%{uclname} System Security GTK GNOME

%files
%dir %{_datadir}/%{name}

%{_bindir}/%{name}
%{_bindir}/%{name}-cli

%{_datadir}/%{name}/otpclient.ui
%{_datadir}/%{name}/add_popover.ui
%{_datadir}/%{name}/settings_popover.ui
%{_datadir}/%{name}/shortcuts.ui
%{_datadir}/%{name}/security_settings.ui
%{_datadir}/applications/com.github.paolostivanin.%{uclname}.desktop
%{_datadir}/metainfo/com.github.paolostivanin.%{uclname}.appdata.xml

%{_mandir}/man1/otpclient-cli.1.gz
%{_mandir}/man1/otpclient.1.gz

%{_datadir}/icons/hicolor/scalable/apps/com.github.paolostivanin.OTPClient-symbolic.svg
%{_datadir}/icons/hicolor/scalable/apps/com.github.paolostivanin.OTPClient.svg

%changelog
* Wed Aug  7 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.0.2:
  * FIX: importing data on a first run (#376)
  * FIX: better error handling
  * IMPROVED: handling of memlock when too low
* Wed Jul 31 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.0.1:
  * CHANGE: switch from PBKDF2 to Argon2id (#358).
    This change is completely transparent to the end user, therefore no action is required.
  * NEW: make Argon2id parameters configurable (#358)
  * NEW: add support for importing plain Aegis txt
  * FIX: various issues related to importing Aegis backups (#371)
  * FIX: improving handling of json files (#369)
  * FIX: parsing QR codes (#374)
  * FIX: show db parameters dynamically
  * FIX: add missing ui file to CMakeLists.txt
* Fri Jun 28 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.7.0:
  * CHANGE: deleting a row, editing a row and showing the qr code
    is now done via right click on the target row (#359).
  * FIX: multiple fixes to QR handling (#364).
  * FIX: exporting to FreeOTP+ format (#367).
  * FIX: updated otpclient and otpclient-cli man pages (thanks @fvcr).
  * FIX: code more readable thanks to macros.
* Thu Mar 14 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.6.0:
  * NEW: add possibility to import plain/encrypted backups
    using the CLI.
  * FIX: make GUI and CLI independent, so that CLI only can be built
    and installed without GTK being present.
  * FIX: check file size against memlock before importing a backup.
  * FIX: code cleanup and internal refactoring.
* Fri Mar  8 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.5.2:
  * NEW: add possibility to export plain/encrypted
    Authenticator Pro/2FAS backups using the CLI.
  * FIX: improve popover layout.
  * FIX: exporting plaing Aegis via CLI.
  * FIX: cleanup code.
* Tue Mar  5 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.5.1:
  * NEW: add back buttons to the various popover menus
  * FIX: split popovers into their own UI files
  * FIX: remove upgrade message when upgrading from a version older than 2.6.0
* Fri Mar  1 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.5.0:
  * NEW: add support for importing and exporting plain/encrypted 2FAS backups (#322)
  * NEW: add support for importing and exporting plain/encrypted AuthenticatorPro backups (#322)
  * CHANGE: show warning when exporting a plain backup
  * CHANGE: remove support for older Glib and GCrypt
  * FIX: add 2fa keyword to the desktop file (#349)
  * FIX: remove custom keywords from metadata file (#348)
  * FIX: returning to a dialog won't crash the widget
* Mon Feb 12 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.4.1:
  * FIX: FreeOTP+ export (thanks @hubnut)
* Sat Feb 10 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.4.0:
  * NEW: CLI was completely refactored, and the options have changed.
    Be sure to check the new options using the help command (-h)
  * NEW: you can now specify a database when calling the CLI (#340)
  * FIX: handling errors when path and/or password is incorrect (#336)
  * FIX: prompt for file again, if needed (#335)
  * FIX: prevent about dialog from hiding
  * FIX: use system RNG as source of entropy
* Wed Feb  7 2024 Pablo Herranz Ramírez <pablo.herranz@suse.com>
- Update to 3.3.0:
  * Set brackground to red when delete mode is entered
  * Fix base32 encoding/decoding
  * Requires libcotp >= 3.0
* Fri Nov  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.2.1:
  * FIX: increase secure memory pool to 64 MB, if possible
  * FIX: parsing of big aegis encrypted json (#309)
  * FIX: better memory management
* Wed Oct 25 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.2.0:
  * NEW: add file chooser dialog on export (#305).
  * FIX: overwrite exported file instead of appending it (#305).
  * FIX: exported file will be accessible only by the current user (#305).
  * FIX: multiple issues related to failed first launch (#303).
  * FIX: couple of issues with secret-service.
* Mon Jul  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.9:
  * Fix db corruption when symbols are used (#301).
  * Fix crash when user changes db multiple times.
* Wed Jun 14 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.8:
  * Fix importing Aegis plain text json (#296).
* Fri May 26 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.7:
  * Add new Database info dialog (Hamburger menu -> Database info)
  * Fix crash when no row is selected (#295)
  * Fix UI when creating/changing a database
  * Multiple fixes when creating a new database
  * Use current db folder when creating/changing database
  * Fix memory leak in case of error when opening the settings dialog
* Wed Mar 22 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.6:
  * Correctly quit the password dialog on export. This avoid dumping
    the database in plaintext format if the user presses either the
    cancel or close button.
* Wed Mar 15 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.5:
  * allow db to be a symlink (fix #289)
* Fri Feb 10 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.4:
  * make auto-lock and secret service mutually exclusive (#279)
  * fix importing plain AEGIS (#281)
  * fix importing encrypted AEGIS on some distros (#281)
  * rename disable_secret_service setting to use_secret_service
* Fri Jan 13 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.3:
  * Fix Aegis import/export when using long pwds.
  * Fix secret service cleanup
  * Show the correct error message when import fails
  * Use g_utf8_strlen instead of strlen
  * Add libcotp >= 2.0 compatibility
* Fri Dec 30 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.1:
  * Fixed some memory leaks.
  * Improved error handling.
  * Use secure functions instead of standard ones .
* Mon Dec 19 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.1.0:
  * New feature (#258): entries can be displayed as a QR-Code
  * All keyboard shortcuts have been revised, be sure to check them (Ctrl-k)
  * Updated the artwork credits in the about dialog
  * Code clean-up
* Fri Dec  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.0.0:
  * NEW: OTPClient is now translatable (#263). If you wish to translate it in your language,
    you can find two templates (.pot) in the po/ directory. When you are done translating, either open a PR or send me an email so I can add the translation.
  * NEW: secret is now editable too (#258)
  * NEW: an About dialog has been added in the settings menu.
  * CHANGED: removed Authenticator Plus support (#257)
* Wed Nov 30 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.6.4:
  * fix issue when importing AEGIS encrypted backups.
* Wed Jul 20 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.6.3:
  * Fix ternary operator logic when setting the google_migration flag.
* Wed Jul  6 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.6.2:
  * Add info message about the new secret service behavior.
* Tue Jul  5 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.6.1:
  * Add ability to import google migration QR also via webcam.
  * Avoid double free on error while importing encrypted aegis.
* Fri Jul  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.6.0:
  * It's now possible to import SVG tokens (in addition to PNG ones).
  * Add support for importing and exporting encrypted Aegis backups.
  * Add support for importing Google migration QR codes (hamburger menu -> import -> Google migration QR).
    You need to provide the QR file (e.g. by taking a screenshot with the webcam or another phone).
  * Fix andOTP import bug.
  * Improve row deletion workflow.
  * Add support for libsecret. By default, the password is saved into the secret service provider of your OS.
    This means that you won't be required a password as long as you're logged in. You can disable this feature from the settings menu.
  * Show a video feed when adding a QR using the webcam.
* Sun Apr  3 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.5.1:
  * enable markup on change database dialog
* Thu Mar 31 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.5.0:
  * NEW: rows can now be reordered. Enable the reordering mode by using
    the "up down" arrows button on the top left, then drag and drop rows where you want (#184)
  * NEW: added a dark theme (enable it settings) (#207)
  * NEW: allow to switch database. This is useful if you have
    multiple OTPClient databases (e.g. work, personal, etc) (#186)
  * NEW: add a button to lock the app (#236)
  * FIX: when app is locked, the content is now hidden (#235)
  * FIX: when clicking cancel on decryption, you can now choose to select another database (#196)
  * FIX: small code improvements
* Mon Feb 28 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.9.1:
  * Fix a regression brought by the previous update (non-utf8 string
    was incorrectly parsed). Now URIs are correctly parsed, whether
    or not they contain utf-8 chars.
* Mon Feb 28 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.9:
  * fix an error when importing a QR code (issue #240)
  * better error handling when importing a code
* Fri Feb 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.8:
  * Fix show next OTP.
  * Correctly decode URIs from QR codes.
* Fri Nov 19 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.7:
  * do not use strlen in for loop
  * do not use strlen to check for empty string
  * update CMakeLists.txt with the correct version
* Mon Nov 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.6:
  * Use secure_strdup when trimming the account key.
  * Use g_memdup2 when available.
  * Fix account/issuer when importing andOTP db.
  * Check for NULL when comparing account and issuer.
* Tue Mar 30 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.4
  * Remove sorting feature, as it's bugged due to an issue with
    GtkTreeView. This feature will come back with v3.0, because
    GtkColumnView will replace GtkTreeView
* Thu Mar 25 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.3
  * remove hard-coded paths (#203 )
  * fix wrong icon in taskbar (#204)
  * fix an error in andOTP export
* Fri Feb 12 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.2
  * fix handling of andOTP data when importing/exporting
* Thu Dec 31 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.1
  * allow user to specify an output folder in the CLI
* Wed Dec 30 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4.0
  * add export command to otpclient-cli
* Fri Jul 24 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.3.2
  * Fix wrong code when entries are sorted
  * new icon
* Wed May 13 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.3.1
  * Fix possible memory leak in freeotp.c
* Tue May 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.3.0
  + Add support for Aeigs backups
* Mon Apr 13 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 2.2.1:
  + Fixed a bug that prevented andOTP backup encrypted using a long
    password to be correctly imported.
* Fri Apr 10 2020 Paolo Stivanin <info@paolostivanin.com>
  * Update to version 2.2.0:
  + Add support for FreeOTPPlus.
  + Fix first startup dialog wording.
* Tue Mar 17 2020 Paolo Stivanin <info@paolostivanin.com>
- run spec cleaner.
* Mon Feb 24 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v2.1.0:
  + add restore/create db on first run
  + save sort order on exit
    + allow user to reset the value back to the default
* Thu Dec 19 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v2.0.1:
  + show dialog if memlock value is too low
  + fix memory leak on parse-uri
  + set max pwd length to 255
  + multiple fixes to db handling
  + fix a double free in case of a crash
  + better error handling
* Thu Dec 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v2.0.0
  + add cli
  + add lock
  + add plain text import/export for andotp
  + update andotp encryption code
  + add import from cliboard
  + add sort
* Thu Jun 27 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.5.1
* Thu Jun 20 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.5.0
  + https://github.com/paolostivanin/OTPClient/releases/tag/v1.5.0
* Sun Mar 24 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.4.1
  + fix some flatpak issues
* Tue Mar 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.4.0
  + add full andOTP support
  + minor fixes
* Wed Oct 31 2018 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.3.1
* Sun Oct 21 2018 Paolo Stivanin <info@paolostivanin.com>
- Fix build dep
* Sun Oct 21 2018 Paolo Stivanin <info@paolostivanin.com>
- Update to v1.3.0
* Sat Aug 25 2018 info@paolostivanin.com
- First release on OBS
